@@ -1,11 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """Pycoast package for adding geographic-based decorations to images."""
-from .cw_pil import ContourWriterPIL
-from .cw_agg import ContourWriterAGG  # noqa
 from pycoast.cw_base import get_resolution_from_area  # noqa
+
+from .cw_agg import ContourWriterAGG  # noqa
+from .cw_pil import ContourWriterPIL
 from .version import get_versions
-__version__ = get_versions()['version']
+
+__version__ = get_versions()["version"]
 del get_versions
 
 
@@ -20,6 +22,9 @@ class ContourWriter(ContourWriterPIL):
 
     def __init__(self, *args, **kwargs):
         import warnings
-        warnings.warn("'ContourWriter' has been deprecated please use "
-                      "'ContourWriterPIL' or 'ContourWriterAGG' instead", DeprecationWarning)
+
+        warnings.warn(
+            "'ContourWriter' has been deprecated please use " "'ContourWriterPIL' or 'ContourWriterAGG' instead",
+            DeprecationWarning,
+        )
         super(ContourWriter, self).__init__(*args, **kwargs)
